==> qliksense-extension-tutorial-0.9.0.tgz: package/docs/includes/README.md <==
---
title: README
draft: false
layout: raw
---

# Qlik Sense Extension Tutorial

> A comprehensive tutorial how to create Qlik Sense Visualization Extensions

# About this Tutorial

In this tutorial you'll learn how to use Qlik Sense' Extension concept to bring new visualizations into the Qlik Sense Client.

## Work in Progress, Always

This project is work in progress and will and should always remain in this status, that's part of the concept and the idea of creating a ***living tutorial***. As soon as there are now capabilities exposed in Qlik Sense' Extension API, I will update the appropriate sections here.

If you want to follow the progress of this project there are some options:

* [Join GitHub](https://github.com/join) and "watch" or "star" the project and you'll get updates
* [Follow me on Twitter](http://twitter.com/waltherstefan), as soon as I have finished a new chapter, I'll announce it there

# Chapters

These are the chapters I am about to write ... and some of them are already finished ;-)


{{doc 'toc'}}


## Comments, Feedback & Questions

If you have any questions, found errors, etc., please [create an issue here on GitHub](https://github.com/stefanwalther/qliksense-extension-tutorial/issues).

## Contributing

Found a bug? Have a request? Have a question?
Please [create an issue](https://github.com/stefanwalther/qliksense-extension-tutorial/issues) on GitHub.

## Errata
Due to the nature of this project there is no errata section necessary: This is living tutorial, so as soon as I find errors or mistakes or just want to improve something, I'll just fix it and push it to GitHub.

By doing so, you'll always have access to the latest version.

If you want to follow changes, follow the [Change Log](CHANGELOG.yml).


## Author

**Stefan Walther**

* [github.com/stefanwalther](http://github.com/stefanwalther)
* [twitter.com/waltherstefan](http://twitter.com/waltherstefan)
* [qliksite.io](http://qliksite.io)

## License

This tutorial is made available "AS IS" without any warranty of any kind under the MIT License (MIT).

[Additional license information for this tutorial](https://github.com/stefanwalther/qliksense-extension-tutorial/blob/master/LICENSE.md).


---
**Qlik Sense Visualization Extension Tutorial**

==> qliksense-extension-tutorial-0.12.7.tgz: package/docs/includes/README.md <==
---
title: README
draft: false
layout: raw
---

# Qlik Sense Extension Tutorial
> A comprehensive tutorial how to create Qlik Sense Visualization Extensions

![](http://serve.mod.biz/branch/)

---

# About this Tutorial

In this tutorial you'll learn how to use Qlik Sense' Extension concept to bring new visualizations into the Qlik Sense Client.

## Work in Progress, Always

This project is work in progress and will and should always remain in this status, that's part of the concept and the idea of creating a ***living tutorial***. As soon as there are now capabilities exposed in Qlik Sense' Extension API, I will update the appropriate sections here.

If you want to follow the progress of this project there are some options:

* [Join GitHub](https://github.com/join) and "watch" or "star" [the project](http://github.com/stefanwalther/qliksense-extension-tutorial) and you'll get updates
* [Follow me on Twitter](http://twitter.com/waltherstefan), as soon as I have finished a new chapter, I'll announce it there

# Chapters

These are the chapters I am about to write ... and some of them are already finished ;-)


{{doc 'toc'}}


## Comments, Feedback & Questions

If you have any questions, found errors, etc., please [create an issue here on GitHub](https://github.com/stefanwalther/qliksense-extension-tutorial/issues).

## Contributing

Found a bug? Have a request? Have a question?
Please [create an issue](https://github.com/stefanwalther/qliksense-extension-tutorial/issues) on GitHub.

## Errata
Due to the nature of this project there is no errata section necessary: This is living tutorial, so as soon as I find errors or mistakes or just want to improve something, I'll just fix it and push it to GitHub.

By doing so, you'll always have access to the latest version.

If you want to follow changes, follow the [Change Log](CHANGELOG.yml).


## Author

**Stefan Walther**

* [github.com/stefanwalther](http://github.com/stefanwalther)
* [twitter.com/waltherstefan](http://twitter.com/waltherstefan)
* [qliksite.io](http://qliksite.io)

Thx for contributing:
* [mcgovey](https://github.com/mcgovey)

## License

This tutorial is made available "AS IS" without any warranty of any kind under the MIT License (MIT).

[Additional license information for this tutorial](https://github.com/stefanwalther/qliksense-extension-tutorial/blob/master/LICENSE.md).


---
**Qlik Sense Visualization Extension Tutorial**
